@@ -463,11 +463,13 @@ class Decorators:
             pass
 
     # Mainterinancing -------------------------------------------------------
-    def maintain (self, f):
-        if not self._started:
-            assert f.__name__ not in self._maintern_funcs, "maintain func {} is already exists".format (f.__name__)
-        self._maintern_funcs [f.__name__] = f
-        return f
+    def maintain (self, interval = 1):
+        def decorator(f):
+            if not self._started:
+                assert f.__name__ not in self._maintern_funcs, "maintain func {} is already exists".format (f.__name__)
+            self._maintern_funcs [f.__name__] = (f, interval)
+            return f
+        return decorator
 
     # Error handling ------------------------------------------------------
     def add_error_handler (self, errcode, f, **k):
